@@ -83,7 +83,7 @@ class ClsClient(AbstractClient):
 
 
     def CreateAlarmNotice(self, request):
-        """该接口用户创建告警通知模板。
+        """该接口用户创建通知渠道组。
 
         :param request: Request instance for CreateAlarmNotice.
         :type request: :class:`tencentcloud.cls.v20201016.models.CreateAlarmNoticeRequest`
@@ -110,62 +110,6 @@ class ClsClient(AbstractClient):
                 raise TencentCloudSDKException(e.message, e.message)
 
 
-    def CreateAsyncContextTask(self, request):
-        """本接口用于创建异步上下文任务
-
-        :param request: Request instance for CreateAsyncContextTask.
-        :type request: :class:`tencentcloud.cls.v20201016.models.CreateAsyncContextTaskRequest`
-        :rtype: :class:`tencentcloud.cls.v20201016.models.CreateAsyncContextTaskResponse`
-
-        """
-        try:
-            params = request._serialize()
-            body = self.call("CreateAsyncContextTask", params)
-            response = json.loads(body)
-            if "Error" not in response["Response"]:
-                model = models.CreateAsyncContextTaskResponse()
-                model._deserialize(response["Response"])
-                return model
-            else:
-                code = response["Response"]["Error"]["Code"]
-                message = response["Response"]["Error"]["Message"]
-                reqid = response["Response"]["RequestId"]
-                raise TencentCloudSDKException(code, message, reqid)
-        except Exception as e:
-            if isinstance(e, TencentCloudSDKException):
-                raise
-            else:
-                raise TencentCloudSDKException(e.message, e.message)
-
-
-    def CreateAsyncSearchTask(self, request):
-        """本接口用于创建异步检索任务
-
-        :param request: Request instance for CreateAsyncSearchTask.
-        :type request: :class:`tencentcloud.cls.v20201016.models.CreateAsyncSearchTaskRequest`
-        :rtype: :class:`tencentcloud.cls.v20201016.models.CreateAsyncSearchTaskResponse`
-
-        """
-        try:
-            params = request._serialize()
-            body = self.call("CreateAsyncSearchTask", params)
-            response = json.loads(body)
-            if "Error" not in response["Response"]:
-                model = models.CreateAsyncSearchTaskResponse()
-                model._deserialize(response["Response"])
-                return model
-            else:
-                code = response["Response"]["Error"]["Code"]
-                message = response["Response"]["Error"]["Message"]
-                reqid = response["Response"]["RequestId"]
-                raise TencentCloudSDKException(code, message, reqid)
-        except Exception as e:
-            if isinstance(e, TencentCloudSDKException):
-                raise
-            else:
-                raise TencentCloudSDKException(e.message, e.message)
-
-
     def CreateConfig(self, request):
         """创建采集规则配置
 
@@ -194,8 +138,36 @@ class ClsClient(AbstractClient):
                 raise TencentCloudSDKException(e.message, e.message)
 
 
+    def CreateConsumer(self, request):
+        """本接口用于创建投递任务
+
+        :param request: Request instance for CreateConsumer.
+        :type request: :class:`tencentcloud.cls.v20201016.models.CreateConsumerRequest`
+        :rtype: :class:`tencentcloud.cls.v20201016.models.CreateConsumerResponse`
+
+        """
+        try:
+            params = request._serialize()
+            body = self.call("CreateConsumer", params)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.CreateConsumerResponse()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
     def CreateExport(self, request):
-        """本接口用于创建日志导出
+        """本接口用于创建日志下载任务
 
         :param request: Request instance for CreateExport.
         :type request: :class:`tencentcloud.cls.v20201016.models.CreateExportRequest`
@@ -391,7 +363,7 @@ class ClsClient(AbstractClient):
 
 
     def DeleteAlarmNotice(self, request):
-        """该接口用于删除告警通知模板
+        """该接口用于删除通知渠道组
 
         :param request: Request instance for DeleteAlarmNotice.
         :type request: :class:`tencentcloud.cls.v20201016.models.DeleteAlarmNoticeRequest`
@@ -418,62 +390,6 @@ class ClsClient(AbstractClient):
                 raise TencentCloudSDKException(e.message, e.message)
 
 
-    def DeleteAsyncContextTask(self, request):
-        """本接口用于删除异步上下文任务
-
-        :param request: Request instance for DeleteAsyncContextTask.
-        :type request: :class:`tencentcloud.cls.v20201016.models.DeleteAsyncContextTaskRequest`
-        :rtype: :class:`tencentcloud.cls.v20201016.models.DeleteAsyncContextTaskResponse`
-
-        """
-        try:
-            params = request._serialize()
-            body = self.call("DeleteAsyncContextTask", params)
-            response = json.loads(body)
-            if "Error" not in response["Response"]:
-                model = models.DeleteAsyncContextTaskResponse()
-                model._deserialize(response["Response"])
-                return model
-            else:
-                code = response["Response"]["Error"]["Code"]
-                message = response["Response"]["Error"]["Message"]
-                reqid = response["Response"]["RequestId"]
-                raise TencentCloudSDKException(code, message, reqid)
-        except Exception as e:
-            if isinstance(e, TencentCloudSDKException):
-                raise
-            else:
-                raise TencentCloudSDKException(e.message, e.message)
-
-
-    def DeleteAsyncSearchTask(self, request):
-        """本接口用于删除异步检索任务
-
-        :param request: Request instance for DeleteAsyncSearchTask.
-        :type request: :class:`tencentcloud.cls.v20201016.models.DeleteAsyncSearchTaskRequest`
-        :rtype: :class:`tencentcloud.cls.v20201016.models.DeleteAsyncSearchTaskResponse`
-
-        """
-        try:
-            params = request._serialize()
-            body = self.call("DeleteAsyncSearchTask", params)
-            response = json.loads(body)
-            if "Error" not in response["Response"]:
-                model = models.DeleteAsyncSearchTaskResponse()
-                model._deserialize(response["Response"])
-                return model
-            else:
-                code = response["Response"]["Error"]["Code"]
-                message = response["Response"]["Error"]["Message"]
-                reqid = response["Response"]["RequestId"]
-                raise TencentCloudSDKException(code, message, reqid)
-        except Exception as e:
-            if isinstance(e, TencentCloudSDKException):
-                raise
-            else:
-                raise TencentCloudSDKException(e.message, e.message)
-
-
     def DeleteConfig(self, request):
         """删除采集规则配置
 
@@ -530,8 +446,36 @@ class ClsClient(AbstractClient):
                 raise TencentCloudSDKException(e.message, e.message)
 
 
+    def DeleteConsumer(self, request):
+        """本接口用于删除投递配置
+
+        :param request: Request instance for DeleteConsumer.
+        :type request: :class:`tencentcloud.cls.v20201016.models.DeleteConsumerRequest`
+        :rtype: :class:`tencentcloud.cls.v20201016.models.DeleteConsumerResponse`
+
+        """
+        try:
+            params = request._serialize()
+            body = self.call("DeleteConsumer", params)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.DeleteConsumerResponse()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
     def DeleteExport(self, request):
-        """本接口用于删除日志导出
+        """本接口用于删除日志下载任务
 
         :param request: Request instance for DeleteExport.
         :type request: :class:`tencentcloud.cls.v20201016.models.DeleteExportRequest`
@@ -559,7 +503,7 @@ class ClsClient(AbstractClient):
 
 
     def DeleteIndex(self, request):
-        """本接口用于日志主题的索引配置
+        """本接口用于删除日志主题的索引配置，删除索引配置后将无法检索和查询采集到的日志。
 
         :param request: Request instance for DeleteIndex.
         :type request: :class:`tencentcloud.cls.v20201016.models.DeleteIndexRequest`
@@ -699,7 +643,7 @@ class ClsClient(AbstractClient):
 
 
     def DescribeAlarmNotices(self, request):
-        """该接口用于获取告警通知模板列表
+        """该接口用于获取通知渠道组列表
 
         :param request: Request instance for DescribeAlarmNotices.
         :type request: :class:`tencentcloud.cls.v20201016.models.DescribeAlarmNoticesRequest`
@@ -727,7 +671,7 @@ class ClsClient(AbstractClient):
 
 
     def DescribeAlarms(self, request):
-        """本接口用于获取告警策略。
+        """本接口用于获取告警策略列表。
 
         :param request: Request instance for DescribeAlarms.
         :type request: :class:`tencentcloud.cls.v20201016.models.DescribeAlarmsRequest`
@@ -754,118 +698,6 @@ class ClsClient(AbstractClient):
                 raise TencentCloudSDKException(e.message, e.message)
 
 
-    def DescribeAsyncContextResult(self, request):
-        """本接口用户获取异步上下文任务的结果
-
-        :param request: Request instance for DescribeAsyncContextResult.
-        :type request: :class:`tencentcloud.cls.v20201016.models.DescribeAsyncContextResultRequest`
-        :rtype: :class:`tencentcloud.cls.v20201016.models.DescribeAsyncContextResultResponse`
-
-        """
-        try:
-            params = request._serialize()
-            body = self.call("DescribeAsyncContextResult", params)
-            response = json.loads(body)
-            if "Error" not in response["Response"]:
-                model = models.DescribeAsyncContextResultResponse()
-                model._deserialize(response["Response"])
-                return model
-            else:
-                code = response["Response"]["Error"]["Code"]
-                message = response["Response"]["Error"]["Message"]
-                reqid = response["Response"]["RequestId"]
-                raise TencentCloudSDKException(code, message, reqid)
-        except Exception as e:
-            if isinstance(e, TencentCloudSDKException):
-                raise
-            else:
-                raise TencentCloudSDKException(e.message, e.message)
-
-
-    def DescribeAsyncContextTasks(self, request):
-        """本接口用于获取异步上下文任务列表
-
-        :param request: Request instance for DescribeAsyncContextTasks.
-        :type request: :class:`tencentcloud.cls.v20201016.models.DescribeAsyncContextTasksRequest`
-        :rtype: :class:`tencentcloud.cls.v20201016.models.DescribeAsyncContextTasksResponse`
-
-        """
-        try:
-            params = request._serialize()
-            body = self.call("DescribeAsyncContextTasks", params)
-            response = json.loads(body)
-            if "Error" not in response["Response"]:
-                model = models.DescribeAsyncContextTasksResponse()
-                model._deserialize(response["Response"])
-                return model
-            else:
-                code = response["Response"]["Error"]["Code"]
-                message = response["Response"]["Error"]["Message"]
-                reqid = response["Response"]["RequestId"]
-                raise TencentCloudSDKException(code, message, reqid)
-        except Exception as e:
-            if isinstance(e, TencentCloudSDKException):
-                raise
-            else:
-                raise TencentCloudSDKException(e.message, e.message)
-
-
-    def DescribeAsyncSearchResult(self, request):
-        """本接口用户获取异步检索任务的结果
-
-        :param request: Request instance for DescribeAsyncSearchResult.
-        :type request: :class:`tencentcloud.cls.v20201016.models.DescribeAsyncSearchResultRequest`
-        :rtype: :class:`tencentcloud.cls.v20201016.models.DescribeAsyncSearchResultResponse`
-
-        """
-        try:
-            params = request._serialize()
-            body = self.call("DescribeAsyncSearchResult", params)
-            response = json.loads(body)
-            if "Error" not in response["Response"]:
-                model = models.DescribeAsyncSearchResultResponse()
-                model._deserialize(response["Response"])
-                return model
-            else:
-                code = response["Response"]["Error"]["Code"]
-                message = response["Response"]["Error"]["Message"]
-                reqid = response["Response"]["RequestId"]
-                raise TencentCloudSDKException(code, message, reqid)
-        except Exception as e:
-            if isinstance(e, TencentCloudSDKException):
-                raise
-            else:
-                raise TencentCloudSDKException(e.message, e.message)
-
-
-    def DescribeAsyncSearchTasks(self, request):
-        """本接口用户获取异步检索任务列表
-
-        :param request: Request instance for DescribeAsyncSearchTasks.
-        :type request: :class:`tencentcloud.cls.v20201016.models.DescribeAsyncSearchTasksRequest`
-        :rtype: :class:`tencentcloud.cls.v20201016.models.DescribeAsyncSearchTasksResponse`
-
-        """
-        try:
-            params = request._serialize()
-            body = self.call("DescribeAsyncSearchTasks", params)
-            response = json.loads(body)
-            if "Error" not in response["Response"]:
-                model = models.DescribeAsyncSearchTasksResponse()
-                model._deserialize(response["Response"])
-                return model
-            else:
-                code = response["Response"]["Error"]["Code"]
-                message = response["Response"]["Error"]["Message"]
-                reqid = response["Response"]["RequestId"]
-                raise TencentCloudSDKException(code, message, reqid)
-        except Exception as e:
-            if isinstance(e, TencentCloudSDKException):
-                raise
-            else:
-                raise TencentCloudSDKException(e.message, e.message)
-
-
     def DescribeConfigMachineGroups(self, request):
         """获取采集规则配置所绑定的机器组
 
@@ -922,8 +754,36 @@ class ClsClient(AbstractClient):
                 raise TencentCloudSDKException(e.message, e.message)
 
 
+    def DescribeConsumer(self, request):
+        """本接口用于获取投递配置
+
+        :param request: Request instance for DescribeConsumer.
+        :type request: :class:`tencentcloud.cls.v20201016.models.DescribeConsumerRequest`
+        :rtype: :class:`tencentcloud.cls.v20201016.models.DescribeConsumerResponse`
+
+        """
+        try:
+            params = request._serialize()
+            body = self.call("DescribeConsumer", params)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.DescribeConsumerResponse()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
     def DescribeExports(self, request):
-        """本接口用于获取日志导出列表
+        """本接口用于获取日志下载任务列表
 
         :param request: Request instance for DescribeExports.
         :type request: :class:`tencentcloud.cls.v20201016.models.DescribeExportsRequest`
@@ -1315,7 +1175,7 @@ class ClsClient(AbstractClient):
 
 
     def ModifyAlarmNotice(self, request):
-        """该接口用于修改告警通知模板。
+        """该接口用于修改通知渠道组
 
         :param request: Request instance for ModifyAlarmNotice.
         :type request: :class:`tencentcloud.cls.v20201016.models.ModifyAlarmNoticeRequest`
@@ -1370,6 +1230,34 @@ class ClsClient(AbstractClient):
                 raise TencentCloudSDKException(e.message, e.message)
 
 
+    def ModifyConsumer(self, request):
+        """本接口用于修改投递任务
+
+        :param request: Request instance for ModifyConsumer.
+        :type request: :class:`tencentcloud.cls.v20201016.models.ModifyConsumerRequest`
+        :rtype: :class:`tencentcloud.cls.v20201016.models.ModifyConsumerResponse`
+
+        """
+        try:
+            params = request._serialize()
+            body = self.call("ModifyConsumer", params)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.ModifyConsumerResponse()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
     def ModifyIndex(self, request):
         """本接口用于修改索引配置
 
@@ -1539,7 +1427,7 @@ class ClsClient(AbstractClient):
 
 
     def SearchLog(self, request):
-        """本接口用于搜索日志
+        """本接口用于检索分析日志, 该接口除受默认接口请求频率限制外，针对单个日志主题，查询并发数不能超过15。
 
         :param request: Request instance for SearchLog.
         :type request: :class:`tencentcloud.cls.v20201016.models.SearchLogRequest`
@@ -1594,7 +1482,7 @@ class ClsClient(AbstractClient):
                 raise TencentCloudSDKException(e.message, e.message)
 
 
-    def UploadLog(self, request):
+    def UploadLog(self, request, body):
         """## 功能描述
 
         本接口用于将日志写入到指定的日志主题。
@@ -1612,22 +1500,7 @@ class ClsClient(AbstractClient):
         此外日志服务还为用户提供以下两种不同的日志上传模式：
 
 
-        ## 请求
-
-        #### 请求头业务参数
-
-        X-CLS-HashKey 请求头表示日志根据 hashkey 路由写入到 CLS 对应范围的主题分区，以保证写入到的每个主题分区是严格有序的，便于消费时有序消费。
-
-        | 字段名             | 类型   | 位置   | 是否必须 | 含义                                                         |
-        | ------------------ | ------ | ------ | -------- | ------------------------------------------------------------ |
-        | X-CLS-HashKey      | string | header | 否       | 根据 hashkey 写入相应范围的主题分区                          |
-        | X-CLS-TopicId      | String | header | 是       | 主题id                                                       |                                                 |
-        | Content-Type       | String | header | 是       | 请求参数的协议类型， 目前只支持pb协议，填写 "application/octet-stream" |
-        | X-TC-Action        | String |	header | 是       | 公共参数，本接口取值：UploadLog。
-        | X-TC-Region        | String | header | 是   	  | 公共参数，本接口不需要传递此参数。
-        | X-TC-Version       | String | header | 是       | 公共参数，本接口取值：2020-10-16。
-
-        #### 输入参数（pb协议）
+        #### 输入参数(pb二进制流，位于body中)
 
         | 字段名       | 类型    | 位置 | 必须 | 含义                                                         |
         | ------------ | ------- | ---- | ---- | ------------------------------------------------------------ |
@@ -1767,8 +1640,8 @@ class ClsClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("UploadLog", params)
-            response = json.loads(body)
+            params = {"X-CLS-"+key: value for key, value in params.items()}
+            response = self.call_octet_stream("UploadLog", params, body)
             if "Error" not in response["Response"]:
                 model = models.UploadLogResponse()
                 model._deserialize(response["Response"])
